"use client";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Form, FormControl, FormField, FormItem, FormMessage } from "@/components/ui/form";
import { Label } from "@/components/ui/label";
import { Textarea } from "@/components/ui/textarea";
import { ImageBaseUrl } from "@/configs/api";
import { cn } from "@/lib/utils";
import { addRatingComment } from "@/servers/actions/rating-comment-action";
import { zodResolver } from "@hookform/resolvers/zod";
import { motion } from "framer-motion";
import Cookies from "js-cookie";
import { Star } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";
import { useRouter } from "next/navigation";
import { useEffect, useState, useTransition } from "react";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import * as z from "zod";
import BlurFade from "../ui/blur-fade";


export default function SubmitReviewForm({ product }: { product: any }) {
	const t = useTranslations();
	const router = useRouter();
	const isRTL = useLocale() === "ar";
	const [hoverRating, setHoverRating] = useState<number>(0);
	const [isPending, startTransition] = useTransition();

	const formSchema = z.object({
		rating: z.number().min(1, t("Star rating is required")).max(5),
		comment: z.string().optional()
	}).refine((data) => {
		// If there's a comment, rating must exist
		if (data.comment && data.comment.length > 0) {
			return data.rating >= 1;
		}
		return true;
	}, {
		message: t("Please select a rating before adding a comment"),
		path: ["rating"]
	});

	type FormValues = z.infer<typeof formSchema>;

	const form = useForm<FormValues>({
		resolver: zodResolver(formSchema),
		defaultValues: {
			rating: product?.user_review?.rating,
			comment: "",
		},
	});

	// Add useEffect to update form value when product data changes
	useEffect(() => {
		if (product?.user_review?.rating) {
			form.setValue("rating", product.user_review.rating);
			console.log("Setting rating value to:", product.user_review.rating);
		}
	}, [product, form]);


	console.log("Product data:", product);
	console.log("Form values:", form.getValues());

	const { formState: { errors } } = form;


	const onSubmit = async (values: FormValues) => {
		const _session = Cookies.get("__t");

		if (!_session) {
			toast.error(t("Please login to rate this product"));
			return;
		}

		if (!product?.can_review) {
			toast.error(t("You can't rate this product before purchasing it"));
			return;
		}

		console.log("Form submitted with:", values);

		startTransition(async () => {
			try {
				const result = await addRatingComment({
					product_id: product?.id,
					rating: values?.rating,
					comment: values?.comment ?? ""
				});
				if (result?.success) {
					toast.success(t(result?.message?.replace(".", "")), {
						style: { backgroundColor: "green", color: "white" },
					});

					form.reset();
				} else {
					toast.error(t(result?.message?.replace(".", "")));
					if (result?.status === 401) router.push("/login");
				}
			} catch (error: any) {
				toast.error(t("Something went wrong"));
			}
		});
	};

	const imagePath = product?.image?.image_path;
	const imageSrc = imagePath ? ImageBaseUrl + product?.image?.image_path : "/default-image.png";
	const imageAlt = product?.image?.name || "Product image";

	return (
		<div dir="rtl" className="container mx-auto mt-8 px-4 py-12 font-sans">
			<div className="grid grid-cols-1 md:grid-cols-2 gap-8 items-start">
				<Card className="w-full h-full rounded-lg shadow-sm" style={{ backgroundColor: "rgb(246 247 251 / 44%)" }}>
					<CardHeader className="text-right">
						<CardTitle className="text-2xl font-bold">رأيك يهمنا ويساعدنا على تقديم الأفضل دائماً</CardTitle>
						<CardDescription className="mt-2 text-muted-foreground">
							إذا جربت هذا المنتج، شاركنا تجربتك سواء كانت إيجابية أو تتضمن اقتراحات للتحسين. نحن نقرأ كل التعليقات بعناية ونسعى دائماً للتطوير خدماتنا ومنتجاتنا بناءً على ملاحظاتكم.
						</CardDescription>
					</CardHeader>
					<CardContent className="pt-4" style={{ backgroundColor: "rgba(246, 247, 251, 1)" }}>
						<Form {...form}>
							<form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6 text-right">
								<FormField
									control={form.control}
									name="rating"
									render={({ field: { onChange, value } }) => (
										<FormItem>
											<Label htmlFor="rating" className="text-base font-semibold">تقييمك للمنتج</Label>
											<FormControl>
												<div id="rating" className="flex items-center justify-start space-x-1" dir="rtl">
													{[...Array(5)].map((_, index) => {
														const starValue = index + 1;
														return (
															<Star
																key={starValue}
																className={cn(
																	"h-6 w-6 cursor-pointer transition-colors",
																	{
																		"text-yellow-500 fill-yellow-500": hoverRating >= starValue || value >= starValue,
																		"text-gray-300 fill-white dark:text-gray-600": hoverRating < starValue && value < starValue,
																	}
																)}
																onMouseEnter={() => setHoverRating(starValue)}
																onMouseLeave={() => setHoverRating(0)}
																onClick={() => {
																	onChange(starValue);
																	console.log("Star clicked, new value:", starValue);
																}}
																aria-label={`Rate ${starValue} out of ${5} stars`}
															/>
														);
													})}
												</div>
											</FormControl>
											<FormMessage className="text-sm text-red-500" />
										</FormItem>
									)}
								/>

								<FormField
									control={form.control}
									name="comment"
									render={({ field }) => (
										<FormItem>
											<Label htmlFor="comment" className="text-base font-semibold">التعليق</Label>
											<FormControl>
												<Textarea
													id="comment"
													placeholder="أدخل تعليقك هنا..."
													className={cn(
														"min-h-[100px] text-right rounded-md bg-white",
														errors.comment && "border-red-500 focus-visible:ring-red-500"
													)}
													rows={8}
													{...field}
												/>
											</FormControl>
											<FormMessage className="text-sm text-red-500" />
										</FormItem>
									)}
								/>

								<div className="text-left">
									<Button
										type="submit"
										disabled={isPending}
										className="w-full md:w-auto bg-blue-600 hover:bg-blue-700 text-white rounded-md px-6 py-2"
									>
										{isPending ? "جاري الإرسال..." : "إرسال"}
									</Button>
								</div>
							</form>
						</Form>
					</CardContent>
				</Card>

				<BlurFade
					key="main-image-fade"
					className={cn(
						"relative lg:col-span-1"
					)}
				>
					<motion.div
						className="absolute -left-4 -top-4 h-full w-full bg-custom-border rounded-lg"
						initial={{ opacity: 0, scale: 0.8 }}
						animate={{ opacity: 1, scale: 1 }}
						transition={{ duration: 0.5 }}
					/>
					<motion.div
						initial={{ opacity: 0, y: 20 }}
						animate={{ opacity: 1, y: 0 }}
						transition={{ duration: 0.5, delay: 0.2 }}
						dir={isRTL ? "ltr" : "rtl"}
					>
						<Image
							src={imageSrc}
							alt={imageAlt}
							width={630}
							height={577}
							className="relative z-10 h-[500px] w-[630px] rounded-lg object-cover drop-shadow-[2px_2px_2px_rgba(0,0,0,0.5)] filter"
						/>
					</motion.div>
				</BlurFade>
			</div>
		</div>
	);
}
